pub struct ComputationManagerConfig { /* private fields */ }Expand description
Configuration for the ComputationManager.
TODO: Consider making this a registry of computation configs using Box<dyn ComputationConfig>
to support dynamic computation registration. This would allow adding new computation types
without modifying this struct. For now, we hardcode the three computation types.
Implementations
Sourceimpl ComputationManagerConfig
impl ComputationManagerConfig
Sourcepub fn with_depth_slippage_threshold(self, threshold: f64) -> Self
pub fn with_depth_slippage_threshold(self, threshold: f64) -> Self
Sets the slippage threshold for pool depth computation.
Sourcepub fn with_max_hop(self, hop_count: usize) -> Self
pub fn with_max_hop(self, hop_count: usize) -> Self
Sets the max hop count for token gas price computation.
Sourcepub fn with_gas_token(self, gas_token: Address) -> Self
pub fn with_gas_token(self, gas_token: Address) -> Self
Sets the gas token address.
Sourcepub fn depth_slippage_threshold(&self) -> f64
pub fn depth_slippage_threshold(&self) -> f64
Returns the depth slippage threshold.