Module IERC20LayoutProbe

Module IERC20LayoutProbe 

Module containing a contract’s types and functions.

interface IERC20LayoutProbe {
    function balanceOf(address account) external view returns (uint256);
    function allowance(address owner, address spender) external view returns (uint256);
}

Structs

allowanceCall
Function with signature allowance(address,address) and selector 0xdd62ed3e.
allowanceReturn
Container type for the return parameters of the allowance(address,address) function.
balanceOfCall
Function with signature balanceOf(address) and selector 0x70a08231.
balanceOfReturn
Container type for the return parameters of the balanceOf(address) function.

Enums

IERC20LayoutProbeCalls
Container for all the IERC20LayoutProbe function calls.