pub struct TaskQueueHandle { /* private fields */ }Expand description
Handle for enqueueing tasks.
This is cloned and shared with HTTP handlers.
Implementations
Sourceimpl TaskQueueHandle
impl TaskQueueHandle
Sourcepub async fn enqueue(
&self,
order: Order,
) -> Result<SingleOrderQuote, SolveError>
pub async fn enqueue( &self, order: Order, ) -> Result<SingleOrderQuote, SolveError>
Enqueues a solve request and returns a future that resolves to the result.
Returns an error if the queue is full.
Sourcepub fn from_sender(sender: Sender<SolveTask>) -> Self
pub fn from_sender(sender: Sender<SolveTask>) -> Self
Creates a TaskQueueHandle from an existing sender.
This is primarily useful for testing with mock channels.