What an algorithm is given to solve one order. What an algorithm is given to solve one order.
Structs
- Solve
Parts - A
SolveRequesttaken apart, so an algorithm owns the market and the derived data. - Solve
Request - One order to solve, and everything the algorithm reads to solve it.