pub struct SolverParts { /* private fields */ }Expand description
Raw components of a Solver, for callers adding their own layer (e.g., an HTTP server).
Obtained via Solver::into_parts.
Implementations
Sourceimpl SolverParts
impl SolverParts
Sourcepub fn router_address(&self) -> &Bytes
pub fn router_address(&self) -> &Bytes
Returns the Tycho Router contract address for this chain.
Sourcepub fn worker_pools(&self) -> &[WorkerPool]
pub fn worker_pools(&self) -> &[WorkerPool]
Returns a reference to the worker pools.
Sourcepub fn market_data(&self) -> &SharedMarketDataRef
pub fn market_data(&self) -> &SharedMarketDataRef
Returns a reference to the shared market data.
Sourcepub fn derived_data(&self) -> &SharedDerivedDataRef
pub fn derived_data(&self) -> &SharedDerivedDataRef
Returns a reference to the shared derived data.
Sourcepub fn into_router(self) -> WorkerPoolRouter
pub fn into_router(self) -> WorkerPoolRouter
Consumes the parts and returns the router.
Sourcepub fn into_components(
self,
) -> (WorkerPoolRouter, Vec<WorkerPool>, SharedMarketDataRef, SharedDerivedDataRef, JoinHandle<()>, JoinHandle<()>, JoinHandle<()>, Sender<()>)
pub fn into_components( self, ) -> (WorkerPoolRouter, Vec<WorkerPool>, SharedMarketDataRef, SharedDerivedDataRef, JoinHandle<()>, JoinHandle<()>, JoinHandle<()>, Sender<()>)
Consumes the parts, returning all owned components.